﻿using System;
using System.Collections.Generic;
using Opalis.QuickIntegrationKit;
using System.Text;

namespace Utilities.Text
{
    [OpalisData("Line")]
    public class Line
    {
        private String line = String.Empty;

        internal Line(String line)
        {
            this.line = line;
        }

        [OpalisOutput,OpalisFilter]
        public String OutputLine
        {
            get { return line; }
        }
    }

    [OpalisObject("Split Lines",Description="Spawns new workflow for each line in passed text")]
    public class SplitLines : IOpalisObject
    {
        private String inputString;

        public void Design(IOpalisDesigner designer)
        {
            designer.AddInput("Input String");
            designer.AddCorellatedData(typeof(Line));
        }

        public void Execute(IOpalisRequest request, IOpalisResponse response)
        {
            inputString = request.Inputs["Input String"].AsString();
            try
            {
                response.PublishRange(getLines());
            }
            catch (Exception ex)
            {
                response.ReportErrorEvent("Failed to parse line", ex.ToString());
            }
        }

        private IEnumerable<Line> getLines()
        {
            String[] inputStringArray = inputString.Split('\n');
            foreach (String outputString in inputStringArray)
            {
                yield return new Line(outputString);
            }     
        }
    }
}